@@ -18,7 +18,7 @@
 #include <QString>
 #include <QThread>
 #include <QUrl>
-#include <QVector>
+#include <QList>
 
 #include <QSignalSpy>
 #include <QTest>
@@ -36,7 +36,7 @@ private Q_SLOTS:
     {
         qRegisterMetaType<QHash<qulonglong, int>>("QHash<qulonglong,int>");
         qRegisterMetaType<QHash<QString, QUrl>>("QHash<QString,QUrl>");
-        qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
+        qRegisterMetaType<QList<qlonglong>>("QList<qlonglong>");
         qRegisterMetaType<QHash<qlonglong, int>>("QHash<qlonglong,int>");
     }
 
@@ -146,8 +146,8 @@ private Q_SLOTS:
 
         musicDb.insertTracksList(mNewTracks, mNewCovers);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 4);
-        QCOMPARE(endInsertRowsSpy.count(), 4);
+        QCOMPARE(beginInsertRowsSpy.count(), 1);
+        QCOMPARE(endInsertRowsSpy.count(), 1);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
@@ -181,8 +181,8 @@ private Q_SLOTS:
 
         musicDb.insertTracksList(newTracks, newCovers);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 7);
-        QCOMPARE(endInsertRowsSpy.count(), 7);
+        QCOMPARE(beginInsertRowsSpy.count(), 2);
+        QCOMPARE(endInsertRowsSpy.count(), 2);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
@@ -201,13 +201,13 @@ private Q_SLOTS:
 
         musicDb.insertTracksList({newTrack}, newCover);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 8);
-        QCOMPARE(endInsertRowsSpy.count(), 8);
-        QCOMPARE(beginRemoveRowsSpy.count(), 0);
-        QCOMPARE(endRemoveRowsSpy.count(), 0);
+        QCOMPARE(beginInsertRowsSpy.count(), 3);
+        QCOMPARE(endInsertRowsSpy.count(), 3);
+        QCOMPARE(beginRemoveRowsSpy.count(), 1);
+        QCOMPARE(endRemoveRowsSpy.count(), 1);
         QCOMPARE(dataChangedSpy.count(), 0);
-        QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews + 8);
-        QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1 + 8);
+        QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews + 7);
+        QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1 + 7);
 
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(0, 0), Qt::DisplayRole), QStringLiteral("Now Playing"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(1, 0), Qt::DisplayRole), QStringLiteral("Recently Played"));
@@ -224,15 +224,14 @@ private Q_SLOTS:
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(12, 0), Qt::DisplayRole), QStringLiteral("genre4"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(13, 0), Qt::DisplayRole), QStringLiteral("genre5"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(14, 0), Qt::DisplayRole), QStringLiteral("genre6"));
-        QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(15, 0), Qt::DisplayRole), QStringLiteral("genre7"));
 
         viewsModel.viewsData()->setEmbeddedCategory(ElisaUtils::Unknown);
         viewsProxyModel.setEmbeddedCategory(ElisaUtils::Unknown);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 8);
-        QCOMPARE(endInsertRowsSpy.count(), 8);
-        QCOMPARE(beginRemoveRowsSpy.count(),1);
-        QCOMPARE(endRemoveRowsSpy.count(), 1);
+        QCOMPARE(beginInsertRowsSpy.count(), 3);
+        QCOMPARE(endInsertRowsSpy.count(), 3);
+        QCOMPARE(beginRemoveRowsSpy.count(), 2);
+        QCOMPARE(endRemoveRowsSpy.count(), 2);
         QCOMPARE(dataChangedSpy.count(), 0);
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews);
